#[repr(u8)]pub enum Ec {
_RESERVED_0 = 0,
Transone = 1,
Transtwo = 2,
Transthree = 3,
}Variants
_RESERVED_0 = 0
Transone = 1
1 transaction.
Transtwo = 2
2 transactions to be issued for this endpoint per microframe.
Transthree = 3
3 transactions to be issued for this endpoint per microframe.
Implementations